import 'package:ez_localization/ez_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_easy_utils/flutter_easy_utils.dart';
import 'package:flutter_easy_utils/src/providers/LocaleProvider.dart';
import 'package:flutter_easy_utils/src/providers/ThemeProvider.dart';
import 'package:flutter_easy_utils/src/providers/UtilsProvider.dart';
import 'package:flutter_easyloading/flutter_easyloading.dart';
import 'package:provider/provider.dart';

class EasyApp extends StatefulWidget {
  final Widget Function(BuildContext context) builder;
  final Color primary;
  final Color accent;

  @override
  _EasyAppState createState() => _EasyAppState();

  EasyApp({@required this.builder, this.primary : Colors.blue , this.accent : Colors.deepOrangeAccent});
}

class _EasyAppState extends State<EasyApp> {
  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        ChangeNotifierProvider(
          create: (context) => ThemeProvider(),
        ),
        ChangeNotifierProvider(
          create: (context) => LocaleProvider(),
        ),
        ChangeNotifierProvider(
          create: (context) => UtilsProvider(),
        ),
      ],
      child: EzLocalizationBuilder(
          delegate: EzLocalizationDelegate(
            supportedLocales: [
              Locale('en'),
              Locale('ar'),
            ],
          ),
          builder: (context, localizationDelegate) {
            return Consumer2<ThemeProvider, LocaleProvider>(
              builder: (context, theme, locale, child) {
                if (theme.isDarkLoaded) {
                  if (locale.isLocaleLoaded) {
                    return MaterialApp(
                      darkTheme: ThemeData(
                        //fontFamily: 'cairo',
                        brightness: Brightness.dark,
                        accentColor: widget.primary,
                        textTheme: TextTheme(
                          headline1: TextStyle(color: Colors.white),
                          headline6: TextStyle(color: Colors.white),
                          bodyText2: TextStyle(color: Colors.white),
                        ),
                      ),
                      themeMode: theme.isDark == null
                          ? ThemeMode.system
                          : (theme.isDark ? ThemeMode.dark : ThemeMode.light),
                      theme: ThemeData(
                        //fontFamily: 'cairo',
                        brightness: Brightness.light,
                        primarySwatch: widget.primary,
                        accentColor: widget.accent,
                      ),
                      builder: EasyLoading.init(),
                      locale: locale.locale,
                      localizationsDelegates:
                          localizationDelegate.localizationDelegates,
                      supportedLocales: localizationDelegate.supportedLocales,
                      localeResolutionCallback:
                          localizationDelegate.localeResolutionCallback,
                      home: widget.builder(context),
                    );
                  } else {
                    locale.getLocale(context);
                    return IsLoadingWidget();
                  }
                } else {
                  theme.getIsDark();
                  return IsLoadingWidget();
                }
              },
            );
          }),
    );
  }
}
